@@ -2,13 +2,15 @@
 # -*- coding:utf-8 -*-
 
 from python_terraform import *
+from rich.console import Console
+from rich.table import Table
 import argparse
-import logging
 import json
 import sys
 import os
 
 from tempor import ROOT_DIR
+from tempor.console import console
 from tempor.ssh import (
         check_sshkeys,
         install_ssh_keys
@@ -21,8 +23,6 @@ from tempor.utils import (
     terraform_installed
 )
 
-logger = logging.getLogger(__name__)
-
 def get_args():
     cfg = get_config()
 
@@ -72,7 +72,7 @@ def get_args():
 
     # Check if provider is set
     if not args.provider:
-        logger.error('Must Specify a Provider')
+        console.print('[red bold]Must Specify a Provider')
         sys.exit(1)
 
     provider = args.provider
@@ -81,10 +81,10 @@ def get_args():
         try:
             api_token = [i['api_token'] for i in cfg['providers'] if i['name'] == provider][0]
         except IndexError:
-            logger.error('API Tokns are required')
+            console.print('[red bold]API Tokns are required')
             sys.exit(1)
     else:
-        logger.error('Providers are required')
+        console.print('[red bold]Providers are required')
         sys.exit(1)
 
     return (provider, api_token, args)
@@ -94,7 +94,7 @@ def main():
     provider, api_token, args = get_args()
     terr_path = terraform_installed()
     if terr_path is None:
-        logger.error('Platform not Supported')
+        console.print('[red bold]Platform not Supported')
         return
 
     t = Terraform(
@@ -104,31 +104,33 @@ def main():
     )
     # make sure terraform is initialized
     ret, stdout, stderr = t.init()
-    logger.debug(f'{ret}\n{stdout}\n{stderr}')
     if ret != 0 and stderr:
-        logger.error('Failed during initialization')
-        logger.error(stderr)
+        console.print('[red bold]Failed during initialization')
+        console.print(f'[red bold]{stderr}')
         return
     
     # now what do we want to do?
     if args.teardown:
-        sys.stdout.write('[i] Tearing down...')
-        sys.stdout.flush()
+        console.print('[i] Tearing down...', end='')
         ret, stdout, stderr = t.destroy()
-        logger.debug(f'{ret}\n{stdout}\n{stderr}')
         if ret != 0 and stderr:
-            logger.error('Failed during Teardown')
-            logger.error(stderr)
+            console.print('[red bold]Failed during Teardown')
+            console.print(f'[red bold]{stderr}')
         rm_hosts(provider)
-        sys.stdout.write('Done.\n')
-        sys.stdout.flush()
+        console.print('Done.')
         return
 
     elif args.list:
         all_hosts = get_hosts()
+
         if provider in all_hosts:
+            table = Table(title="Active VPS'")
+            table.add_column("VPS Name", style="cyan")
+            table.add_column("IP Address", style="magenta")
+
             for host, ip in all_hosts[provider].items():
-                logger.info(f'{host}\t{ip}')
+                table.add_row(host, ip)
+            console.print(table)
         return
 
     # prevent accidental creations
@@ -139,32 +141,25 @@ def main():
         return
 
     # lets plan the config
-    sys.stdout.write('[i] Preparing Configuration...')
-    sys.stdout.flush()
+    console.print('[i] Preparing Configuration...', end='')
     plan_path = f'{ROOT_DIR}/providers/{provider}/files/plan'
     ret, stdout, stderr = t.cmd('plan', f'-out={plan_path}', var={'api_token':api_token, 'num':args.count})
-    logger.debug(f'{ret}\n{stdout}\n{stderr}')
     if ret != 0 and stderr:
-        logger.error('Failed during Planning')
-        logger.error(stderr)
+        console.print('[red bold]Failed during Planning')
+        console.print(f'[red bold]{stderr}')
         return
-    sys.stdout.write('Done.\n')
-    sys.stdout.flush()
+    console.print('Done.')
 
     # now apply the config
-    sys.stdout.write('[i] Creating VPS...')
-    sys.stdout.flush()
+    console.print('[i] Creating VPS...', end='')
     ret, stdout, stderr = t.cmd('apply', plan_path)
-    logger.debug(f'{ret}\n{stdout}\n{stderr}')
     if ret != 0 and stderr:
-        logger.error('Failed during Applying')
-        logger.error(stderr)
+        console.print('[red bold]Failed during Applying')
+        console.print(f'[red bold]{stderr}')
         return
-    sys.stdout.write('Done.\n')
-    sys.stdout.flush()
+    console.print('Done.')
 
-    sys.stdout.write('[i] Configuring SSH Keys...')
-    sys.stdout.flush()
+    console.print('[i] Configuring SSH Keys...')
     # Get Hostname and IP Adress
     output = t.output()
     
@@ -184,12 +179,10 @@ def main():
             new_hosts[hostname] = ip_address
             install_ssh_keys(provider, hostname, ip_address)
 
-    sys.stdout.write('Done.\n')
-    sys.stdout.flush()
 
-    logger.info('SSH Access to VPS now available for:')
+    console.print('SSH Access to VPS now available for:')
     for host in new_hosts:
-        logger.info(f'ssh {host}')
+        console.print(f'ssh {host}')
 
     save_hosts(provider, new_hosts)
 
